@@ -24,10 +24,12 @@ import hashlib
 import html.entities
 import logging
 import os
+import re
 import shelve
 import ssl
 import tempfile
 import time
+import warnings
 import xml.dom
 from http.client import HTTPSConnection
 from urllib.parse import quote_plus
@@ -969,7 +971,7 @@ class _Request:
             conn.close()
         return response_text
 
-    def execute(self, cacheable=False):
+    def execute(self, cacheable: bool = False) -> xml.dom.minidom.Document:
         """Returns the XML DOM response of the POST Request from the server"""
 
         if self.network.is_caching_enabled() and cacheable:
@@ -977,13 +979,12 @@ class _Request:
         else:
             response = self._download_response()
 
-        return minidom.parseString(_string(response).replace("opensearch:", ""))
+        return _parse_response(response)
 
     def _check_response_for_errors(self, response):
         """Checks the response for errors and raises one if any exists."""
-
         try:
-            doc = minidom.parseString(_string(response).replace("opensearch:", ""))
+            doc = _parse_response(response)
         except Exception as e:
             raise MalformedResponseError(self.network, e) from e
 
@@ -1783,13 +1784,18 @@ class Artist(_Taggable):
             return self.listener_count
 
     def is_streamable(self):
-        """Returns True if the artist is streamable."""
-
-        return bool(
-            _number(
-                _extract(self._request(self.ws_prefix + ".getInfo", True), "streamable")
-            )
+        """Returns True if the artist is streamable: always False because Last.fm has
+        deprecated the Radio API."""
+        warnings.warn(
+            "Always returns False. Last.fm has deprecated the Radio API and will "
+            "it at some point. is_streamable() will be removed in pylast 5.0.0. "
+            "See https://www.last.fm/api/radio and "
+            "https://support.last.fm/t/"
+            "is-the-streamable-attribute-broken-it-always-returns-0/39723/3",
+            DeprecationWarning,
+            stacklevel=2,
         )
+        return False
 
     def get_bio(self, section, language=None):
         """
@@ -2130,18 +2136,32 @@ class Track(_Opus):
         return bool(loved)
 
     def is_streamable(self):
-        """Returns True if the track is available at Last.fm."""
-
-        doc = self._request(self.ws_prefix + ".getInfo", True)
-        return _extract(doc, "streamable") == "1"
+        """Returns True if the artist is streamable: always False because Last.fm has
+        deprecated the Radio API."""
+        warnings.warn(
+            "Always returns False. Last.fm has deprecated the Radio API and will "
+            "it at some point. is_streamable() will be removed in pylast 5.0.0. "
+            "See https://www.last.fm/api/radio and "
+            "https://support.last.fm/t/"
+            "is-the-streamable-attribute-broken-it-always-returns-0/39723/3",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return False
 
     def is_fulltrack_available(self):
-        """Returns True if the full track is available for streaming."""
-
-        doc = self._request(self.ws_prefix + ".getInfo", True)
-        return (
-            doc.getElementsByTagName("streamable")[0].getAttribute("fulltrack") == "1"
+        """Returns True if the full track is available for streaming: always False
+        because Last.fm has deprecated the Radio API."""
+        warnings.warn(
+            "Always returns False. Last.fm has deprecated the Radio API and will "
+            "remove it at some point. is_fulltrack_available() will be removed in "
+            "pylast 5.0.0. See https://www.last.fm/api/radio and "
+            "https://support.last.fm/t/"
+            "is-the-streamable-attribute-broken-it-always-returns-0/39723/3",
+            DeprecationWarning,
+            stacklevel=2,
         )
+        return False
 
     def get_album(self):
         """Returns the album object of this track."""
@@ -2950,4 +2970,20 @@ def _unescape_htmlentity(string):
     return string
 
 
+def _parse_response(response: str) -> xml.dom.minidom.Document:
+    response = _string(response).replace("opensearch:", "")
+    try:
+        doc = minidom.parseString(response)
+    except xml.parsers.expat.ExpatError:
+        # Try again. For performance, we only remove when needed in rare cases.
+        doc = minidom.parseString(_remove_invalid_xml_chars(response))
+    return doc
+
+
+def _remove_invalid_xml_chars(string: str) -> str:
+    return re.sub(
+        r"[^\u0009\u000A\u000D\u0020-\uD7FF\uE000-\uFFFD\u10000-\u10FFF]+", "", string
+    )
+
+
 # End of file
